Code Documentation
******************

.. toctree::
    :maxdepth: 2
    
    reference/serialization.rst
    reference/schema.rst
    reference/misc.rst
    reference/pod.rst

Top-level Interface
^^^^^^^^^^^^^^^^^^^

All public elements of the `linaro-json` package are imported directly
in the package's __init__.py. From there you can directly import
anything you want to use.

.. automodule:: linaro_json
